@@ -83,12 +83,14 @@ class DataHandlerForm(forms.ModelForm):
         else:
             raise forms.ValidationError('Invalid value')
 
-    def save(self, *args, **kwargs):
+    def clean(self):
+        super(DataHandlerForm, self).clean()
         self.cleaned_data['Extra1'] = self.cleaned_data['m_4']
         self.cleaned_data['Extra2'] = self.cleaned_data['m_5']
         self.cleaned_data['Extra3'] = self.cleaned_data['m_6']
-        return super(DataHandlerForm, self).save(*args, **kwargs)
+        return self.cleaned_data
 
     class Meta:
         model = NetcashOrder
-        exclude = ['created_at', 'updated_at']
+        exclude = ['created_at', 'updated_at', 'trusted', 'gateway',
+                   'request_ip', 'debug_info']
